@@ -41,62 +41,62 @@ lines_list = [('BAC___3646A', 'Bac ', 3646.0, 'BalmHead'),
             ('HE_2__1640A', 'He 2', 1640.0, 'He I 1640'),
             ('HE_2__4686A', 'He 2', 4686.0, 'He II 4686'),
             ('C__1__8727A', 'C  1', 8727.0, '[C I] 8727'),
-            ('TOTL__9850A', 'TOTL', 9850.0, 'C I 9850+'),
-            ('C_IC__9850A', 'C Ic', 9850.0, '[C I] 9850'),
-            ('TOTL__2326A', 'TOTL', 2326.0, '[C II] 2326+'),
-            ('C__2__1335A', 'C  2', 1335.0, '[C II] 1335'),
-            ('C__2__1761A', 'C  2', 1761.0, '[C II] 1761'),
+            ('TOTL__9850A', 'TOTL', 9850.0, '[C I] 9850'),
+            ('C_IC__9850A', 'C Ic', 9850.0, '[C I] 9850 coll'),
+            ('TOTL__2326A', 'TOTL', 2326.0, 'C II] 2326+'),
+            ('C__2__1335A', 'C  2', 1335.0, 'C II 1335'),
+            ('C__2__1761A', 'C  2', 1761.0, 'C II 1761'),
             ('TOTL__6580A', 'TOTL', 6580.0, '[C II] 6580'),
-            ('C__2__4267A', 'C  2', 4267.0, '[C II] 4267'),
+            ('C__2__4267A', 'C  2', 4267.0, 'C II 4267'),
             ('C__2_1576M', 'C  2', 157.6, '[C II] 157.6m'),
-            ('C__3_9770A', 'C  3', 977.0, '[C III] 977]'),
-            ('C__3__1907A', 'C  3', 1907.0, '[C III] 1907]'),
-            ('C__3__1910A', 'C  3', 1910.0, '[C III] 1910]'),
-            ('C__3__4649A', 'C  3', 4649.0, '[C III] 4649]'),
-            ('C__3__2297A', 'C  3', 2297.0, '[C III] 2297]'),
-            ('TOTL__1549A', 'TOTL', 1549.0, 'C III 1549+'),
-            ('C__4__1549A', 'C  4', 1549.0, '[C III] 1549]'),
-            ('C__4__4659A', 'C  4', 4659.0, '[C IV] 4649]'),
-            ('N__1__5198A', 'N  1', 5198.0, '[N I] 5198]'),
-            ('N__1__5200A', 'N  1', 5200.0, '[N I] 5200]'),
-            ('N__2__5755A', 'N  2', 5755.0, '[N II] 5755]'),
+            ('C__3_9770A', 'C  3', 977.0, '[C III] 977'),
+            ('C__3__1907A', 'C  3', 1907.0, '[C III] 1907'),
+            ('C__3__1910A', 'C  3', 1910.0, '[C III] 1910'),
+            ('C__3__4649A', 'C  3', 4649.0, 'C III 4649'),
+            ('C__3__2297A', 'C  3', 2297.0, 'C III 2297'),
+            ('TOTL__1549A', 'TOTL', 1549.0, 'C IV 1549 totl'),
+            ('C__4__1549A', 'C  4', 1549.0, 'C IV 1549 rec'),
+            ('C__4__4659A', 'C  4', 4659.0, 'C IV 4649'),
+            ('N__1__5198A', 'N  1', 5198.0, '[N I] 5198'),
+            ('N__1__5200A', 'N  1', 5200.0, '[N I] 5200'),
+            ('N__2__5755A', 'N  2', 5755.0, '[N II] 5755'),
             ('N_2R__5755A', 'N 2r', 5755.0, 'N II 5755 rec'),
             ('N__2__6548A', 'N  2', 6548.0, '[N II] 6548'),
             ('N__2__6584A', 'N  2', 6584.0, '[N II] 6584'),
-            ('N__2__2141A', 'N  2', 2141.0, '[N II] 2141'),
-            ('N__2__4239A', 'N  2', 4239.0, '[N II] 4239'),
-            ('N__2__4041A', 'N  2', 4041.0, '[N II] 4041'),
-            ('TOTL__5679A', 'TOTL', 5679.0, '[N II] 5679+'),
+            ('N__2__2141A', 'N  2', 2141.0, 'N II 2141'),
+            ('N__2__4239A', 'N  2', 4239.0, 'N II 4239'),
+            ('N__2__4041A', 'N  2', 4041.0, 'N II 4041'),
+            ('TOTL__5679A', 'TOTL', 5679.0, 'N II 5679 totl'),
             ('N__2_1217M', 'N  2', 121.7, '[N II] 121.7m'),
             ('N__2_2054M', 'N  2', 205.4, '[N II] 205.4m'),
             ('N__3_5721M', 'N  3', 57.21, '[N III] 57.21m'),
-            ('N__3__4641A', 'N  3', 4641.0, '[N III] 4641'),
-            ('TOTL__1750A', 'TOTL', 1750.0, '[N III] 1750+'),
-            ('N__3__4379A', 'N  3', 4379.0, '[N III] 4379'),
-            ('N__4__1485A', 'N  4', 1485.0, '[N IV] 1485'),
-            ('N__4__1719A', 'N  4', 1719.0, '[N IV] 1719'),
-            ('TOTL__1240A', 'TOTL', 1240.0, '[N V] 1240+'),
+            ('N__3__4641A', 'N  3', 4641.0, 'N III 4641'),
+            ('TOTL__1750A', 'TOTL', 1750.0, 'N III] 1750+'),
+            ('N__3__4379A', 'N  3', 4379.0, 'N III 4379'),
+            ('N__4__1485A', 'N  4', 1485.0, 'N IV] 1485'),
+            ('N__4__1719A', 'N  4', 1719.0, 'N IV 1719'),
+            ('TOTL__1240A', 'TOTL', 1240.0, '[N V] 1240 totl'),
             ('N__5__1239A', 'N  5', 1239.0, '[N V] 1239'),
-            ('O__1__7773A', 'O  1', 7773.0, '[O I 7773]'),
-            ('O__1__6300A', 'O  1', 6300.0, '[O I 6300]'),
-            ('O__1__5577A', 'O  1', 5577.0, '[O I 5577]'),
-            ('O__1_6317M', 'O  1', 63.17, '[O I 63.17m]'),
-            ('O__1_1455M', 'O  1', 145.5, '[O I 145.5m]'),
-            ('O_II__3726A', 'O II', 3726.0, '[O II 3726]'),
-            ('O_II__3729A', 'O II', 3729.0, '[O II 3729]'),
-            ('O_II__7323A', 'O II', 7323.0, '[O II 7323]'),
-            ('O_II__7332A', 'O II', 7332.0, '[O II 7332]'),
+            ('O__1__7773A', 'O  1', 7773.0, 'O I 7773'),
+            ('O__1__6300A', 'O  1', 6300.0, '[O I] 6300'),
+            ('O__1__5577A', 'O  1', 5577.0, '[O I] 5577'),
+            ('O__1_6317M', 'O  1', 63.17, '[O I] 63.17m'),
+            ('O__1_1455M', 'O  1', 145.5, '[O I] 145.5m'),
+            ('O_II__3726A', 'O II', 3726.0, '[O II] 3726'),
+            ('O_II__3729A', 'O II', 3729.0, '[O II] 3729'),
+            ('O_II__7323A', 'O II', 7323.0, '[O II] 7323'),
+            ('O_II__7332A', 'O II', 7332.0, '[O II] 7332'),
             ('O_2R__3726A', 'O 2r', 3726.0, 'O II 3726 rec'),
             ('O_2R__3729A', 'O 2r', 3729.0, 'O II 3729 rec'),
             ('O_2R__7323A', 'O 2r', 7323.0, 'O II 7323 rec'),
             ('O_2R__7332A', 'O 2r', 7332.0, 'O II 7332 rec'),
             ('TOTL__3727A', 'TOTL', 3727.0, '[O II] 3727+'),
             ('TOTL__7325A', 'TOTL', 7325.0, '[O II] 7325+'),
-            ('O_II__2471A', 'O II', 2471.0, 'O II 2471'),
+            ('O_II__2471A', 'O II', 2471.0, '[O II] 2471+'),
             ('O__2__4152A', 'O  2', 4152.0, 'O II 4152'),
             ('TOTL__4341A', 'TOTL', 4341.0, 'O II 4341'),
-            ('O__2__4651A', 'O  2', 4651.0, '[O II] 4651'),
-            ('O_2R__4651A', 'O 2r', 4651.0, 'O II 4651+ rec'),
+            ('O__2__4651A', 'O  2', 4651.0, 'O II 4651'),
+            ('O_2R__4651A', 'O 2r', 4651.0, 'O II 4651+'),
             ('TOTL__4363A', 'TOTL', 4363.0, '[O III] 4363'),
             ('REC___4363A', 'Rec ', 4363.0, 'O III 4363 rec'),
             ('O__3__4959A', 'O  3', 4959.0, '[O III] 4959'),
@@ -104,10 +104,10 @@ lines_list = [('BAC___3646A', 'Bac ', 3646.0, 'BalmHead'),
             ('O__3_5180M', 'O  3', 51.8, '[O III] 51.8m'),
             ('O__3_8833M', 'O  3', 88.33, '[O III] 88.33m'),
             ('TOTL__1665A', 'TOTL', 1665.0, '[O III] 1665+'),
-            ('TOTL__1402A', 'TOTL', 1402.0, '[O IV] 1402+'),
-            ('O__4__1342A', 'O  4', 1342.0, '[O IV] 1342'),
+            ('TOTL__1402A', 'TOTL', 1402.0, 'O IV] 1402+'),
+            ('O__4__1342A', 'O  4', 1342.0, 'O IV 1342'),
             ('O__4_2588M', 'O  4', 25.88, '[O IV] 25.88m'),
-            ('TOTL__1218A', 'TOTL', 1218.0, '[O V] 1218+'),
+            ('TOTL__1218A', 'TOTL', 1218.0, 'O V] 1218+'),
             ('O__5__1216A', 'O  5', 1216.0, '[O V] 1216'),
             ('NE_2_1281M', 'Ne 2', 12.81, '[Ne II] 12.81m'),
             ('NE_3__3869A', 'Ne 3', 3869.0, '[Ne III] 3869'),
